@@ -125,13 +125,20 @@ class PackageBuild:
         logging.info('{} clean'.format(self.name))
         run_shell_list([
             'git rm -r --cached .',
+            "tag git tag -l|xargs git tag -d",
             'git add .',
             "git commit -m 'update .gitignore'",
             'git gc --aggressive'
         ])
 
     def git_tags(self):
-        self.repo.create_tag(self.version_manage.version)
+        self.repo.create_tag(f'v{self.version_manage.version}')
+        self.repo.remote().push()
+        self.repo.remote().push(self.repo.tags)
+
+    def git_tags_clear(self):
+        for tag in self.repo.tags:
+            self.repo.delete_tag(tag)
         self.repo.remote().push()
         self.repo.remote().push(self.repo.tags)
 
